/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer], Maksym Zyzak */

/// \file    TrackFitter.h
/// \brief   A class wrapper over clones merger algorithm for the Ca track finder (declaration)
/// \since   19.10.2023

#pragma once  // include this header only once per compilation unit

#include "CaBranch.h"
#include "CaHit.h"
#include "CaSimd.h"
#include "CaTrackParam.h"
#include "CaVector.h"


namespace cbm::algo::ca
{
  class Track;
  class Framework;

  namespace
  {
    using namespace cbm::algo;  // to keep ca:: prefices in the code
  }


  /// Class implements a track fit the CA track finder
  ///
  class TrackFitter {
  public:
    /// Default constructor
    TrackFitter(ca::Framework& algo);

    /// Destructor
    ~TrackFitter();

    /// Copy constructor
    TrackFitter(const TrackFitter&) = delete;

    /// Move constructor
    TrackFitter(TrackFitter&&) = delete;

    /// Copy assignment operator
    TrackFitter& operator=(const TrackFitter&) = delete;

    /// Move assignment operator
    TrackFitter& operator=(TrackFitter&&) = delete;


    /// Fit tracks, found by the CA tracker
    void FitCaTracks();

  private:
    ///-------------------------------
    /// Private methods

  private:
    ///-------------------------------
    /// Data members

    ca::Framework& frAlgo;  ///< Reference to the main track finder algorithm class
  };

}  // namespace cbm::algo::ca
