/* Copyright (C) 2023 Facility for Antiproton and Ion Research in Europe, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Dominik Smith [committer] */

#ifndef TOFCALIBRATE_H
#define TOFCALIBRATE_H 1

#include "CbmTofDigi.h"

#include "tof/CalibrateSetup.h"
#include "tof/Clusterizer.h"

#include <gsl/span>
#include <optional>
#include <sstream>
#include <vector>

#include <xpu/host.h>

#include "PartitionedVector.h"

namespace cbm::algo::tof
{

  /** @struct CalibrateMonitorData
   ** @author Dominik Smith <d.smith@gsi.de>
   ** @since 16 Oct 2023
   ** @brief Monitoring data for calibration
   **/
  struct CalibrateMonitorData {
    xpu::timings fTime;
    size_t fNumDigis            = 0;
    size_t fDigiCalibUnknownRPC = 0;

    std::string print() const
    {
      std::stringstream ss;
      ss << "Calibrate stats: num unknown RPC " << fDigiCalibUnknownRPC << ", time " << fTime.wall() << std::endl;
      return ss.str();
    }
  };

  /** @class Calibrate
 ** @brief Algo class for calibration
 ** @author Dominik Smith <d.smith@gsi.de>
 ** @since 16.10.2023
 **
 **/
  class Calibrate {

  public:
    typedef std::pair<std::vector<CbmTofDigi>, CalibrateMonitorData> resultType;

    /** @brief Algorithm execution
     ** @param digis to calibrate
     ** @return pair: digi timeslice, monitoring data
     **
     ** @note Modifies input digis for time calibration
     **/
    resultType operator()(gsl::span<const CbmTofDigi> digiIn);

    /** @brief Default constructor **/
    Calibrate() {};

    /** @brief Destructor **/
    ~Calibrate() {};

    /** @brief Parameters for TOF hitfinders **/
    tof::CalibrateSetup fTofConfig {};

  private:  // members
  };
}  // namespace cbm::algo::tof

#endif /* TOFCALIBRATE_H */
