/* Copyright (C) 2023 GSI Helmholtzzentrum fuer Schwerionenforschung, Darmstadt
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Sergei Zharko [committer] */

/// \file   RecoResults.h
/// \date   22.10.2023
/// \brief  A structure for reconstructed results: digi-events, hits and tracks
/// \author S.Zharko <s.zharko@gsi.de>

#pragma once

#include <vector>

#include "DigiData.h"
#include "PartitionedSpan.h"
#include "PartitionedVector.h"
#include "ca/core/utils/CaVector.h"
#include "data/sts/Hit.h"

namespace cbm::algo
{
  /// \struct RecoResults
  /// \brief  Structure to keep reconstructed results: digi-events, hits and tracks
  struct RecoResults {
    std::vector<DigiEvent> events;
    PartitionedSpan<sts::Hit> stsHits;
    PartitionedVector<tof::Hit> tofHits;
    ca::Vector<ca::Track> tracks;
    ca::Vector<std::vector<std::pair<uint32_t, uint32_t>>> trackStsHitIndices;
    ca::Vector<std::vector<std::pair<uint32_t, uint32_t>>> trackTofHitIndices;
  };
}  // namespace cbm::algo
