#!/usr/bin/env python3

import os
import sys
import shutil

dataDir = sys.argv[1]
geoSetup = sys.argv[2]
cbmrootConfigPath = "/lustre/cbm/users/mabeyer/cbmroot/build/config.sh"
macroDir = "/lustre/cbm/users/mabeyer/cbmroot/macro/rich/run"
taskId = os.environ.get('SLURM_ARRAY_TASK_ID')
jobId = os.environ.get('SLURM_ARRAY_JOB_ID')

print("dataDir:" + dataDir)

workDir = dataDir + "/workdir/" + jobId + "_" + taskId + "/"
if os.path.exists(workDir):
    shutil.rmtree(workDir)
os.makedirs(workDir)
os.chdir(workDir)

# Settings
nEvents = 1000
urqmdFile  = "/lustre/cbm/prod/gen/urqmd/auau/10gev/centr/urqmd.auau.10gev.centr." + str(taskId).zfill(5) + ".root"
plutoFile  = ""
nElectrons = 5
nPositrons = 5
engine     = 0 # 0: geant3 1: geant4

randomSeed = 0

eventRate = -1e7
tsLength = -1
eventBuilder = "Ideal"
useMC = 1
monitor = 0
resultDir = ""

# Files
fileName = "data"
traFile  = dataDir + fileName + taskId + ".tra.root"
parFile  = dataDir + fileName + taskId + ".par.root"
geoFile  = dataDir + fileName + taskId + ".geo.root"
digiFile = dataDir + fileName + taskId + ".digi.root"
recoFile = dataDir + fileName + taskId + ".reco.root"
qaFile   = dataDir + fileName + taskId + ".qa.root"


traCmd=('root -l -b -q {}/run_transport.C\(\\"{}\\",\\"{}\\",\\"{}\\",\\"{}\\",{},{},{},\\"{}\\",\\"{}\\",{},{}\)').format(macroDir, urqmdFile, traFile, parFile, geoFile, nEvents, nElectrons, nPositrons, plutoFile, geoSetup, engine, randomSeed)
digiCmd=('root -l -b -q {}/run_digi.C\(\\"{}\\",\\"{}\\",\\"{}\\",{},{},{},{},{}\)').format(macroDir, traFile, parFile, digiFile, nEvents, eventRate, tsLength, randomSeed, monitor)
recoCmd=('root -l -b -q {}/run_reco.C\(\\"{}\\",\\"{}\\",\\"{}\\",\\"{}\\",{},\\"{}\\",\\"{}\\",{},{}\)').format(macroDir, traFile, parFile, digiFile, recoFile, nEvents, geoSetup, eventBuilder, useMC, monitor)
qaCmd=('root -l -b -q {}/run_qa.C\(\\"{}\\",\\"{}\\",\\"{}\\",\\"{}\\",\\"{}\\",{},\\"{}\\",\\"{}\\",{}\)').format(macroDir, traFile, parFile, digiFile, recoFile, qaFile, nEvents, geoSetup, resultDir, monitor)

os.system((". {} -a ; {}").format(cbmrootConfigPath, traCmd))
os.system((". {} -a ; {}").format(cbmrootConfigPath, digiCmd))
os.system((". {} -a ; {}").format(cbmrootConfigPath, recoCmd))
os.system((". {} -a ; {}").format(cbmrootConfigPath, qaCmd))
